<?php

/**
 * Generates the options fields that are used in the form.
 */
if ( !function_exists( 'wplanner_fb_fields' ) ) {

	function wplanner_fb_fields() {

		global $allowedtags;
		$wplannerfb_settings = get_option( 'wplannerfb' );
		
		// Gets the unique option id
		if ( isset( $wplannerfb_settings['id'] ) ) {
			$option_name = $wplannerfb_settings['id'];
		}
		else {
			$option_name = 'wplannerfb';
		};

		$settings = get_option( $option_name );
		$options = wplanner_fb_options();
			
		$counter = 0;
		$menu = '';
		$output = '';
		
		foreach ( $options as $value ) {
		   
			$counter++;
			$val = '';
			$select_value = '';
			$checked = '';
			
			// Wrap all options
			if ( ( $value['type'] != "heading" ) && ( $value['type'] != "info" ) && ( $value['type'] != "listdatabase" ) ) {

				// Keep all ids lowercase with no spaces
				$value['id'] = preg_replace( '/[^a-zA-Z0-9._\-]/', '', strtolower($value['id'] ) );

				$id = 'section-' . $value['id'];

				$class = 'section ';
				if ( isset( $value['type'] ) ) {
					$class .= ' section-' . $value['type'];
				}
				if ( isset( $value['class'] ) ) {
					$class .= ' ' . $value['class'];
				}

				$output .= '<div id="' . esc_attr( $id ) .'" class="' . esc_attr( $class ) . '">'."\n";
				$output .= '<h4 class="heading">' . esc_html( $value['name'] ) . '</h4>' . "\n";
				$output .= '<div class="option">' . "\n" . '<div class="controls">' . "\n";
			 }
			
			// Set default value to $val
			if ( isset( $value['std']) ) {
				$val = $value['std'];
			}
			
			// If the option is already saved, ovveride $val
			if ( ( $value['type'] != 'heading' ) && ( $value['type'] != 'info' ) && ( $value['type'] != 'listdatabase' ) ) {
				if ( isset($settings[($value['id'])] ) ) {
						$val = $settings[( $value['id'] )];
						// Striping slashes of non-array options
						if ( !is_array($val) ) {
							$val = stripslashes( $val );
						}
				}
			}
			
			// If there is a description save it for labels
			$explain_value = '';
			if ( isset( $value['desc'] ) ) {
				$explain_value = $value['desc'];
			}
											
			switch ( $value['type'] ) {
			
			// Basic text input
			case 'text':
				$output .= '<input id="' . esc_attr( $value['id'] ) . '" class="wplannerfb-input" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" type="text" value="' . esc_attr( $val ) . '" />';
			break;
			
			// Basic authorization facebook button
			case 'authorization_button':
				global $facebook;
				
				if( isset($facebook) ) {
					$validAuth = false;
					$state = isset($_GET['state']) ? trim($_GET['state']) : '';
					$dbToken = get_option('wplanner_token');
					
					if(trim($dbToken) != "" && $state == "") {
						$facebook->setAccessToken($dbToken);
						
						try {
							// get user profile
							$user_profile = $facebook->api('/me');
							
							if(count($user_profile) > 0){
								$validAuth = true;
								
								$output .= '<p>This plugin is <b>authorized</b> for: <a target="_blank" href="' . ( $user_profile['link'] ) . '">' . $user_profile['name'] . '</a></p>';
								
								// login url
								$loginUrl = $facebook->getLoginUrl(array('scope' => 'email,publish_stream,manage_pages,user_groups,offline_access'));
	
								$output .= '<a href="' . ($loginUrl) . '" style="width: 138px;" class="button-primary">'. (__( 'Authorize this app again', WP_PLANNER_TEXTDOMAIN )) .'</a>';
							}
							
						} catch (wwPP_FacebookApiException $e) {
							
							// clean token
							update_option('wplanner_token', $token);
							
							// refresh page
							echo '
							<script type="text/javascript">
								window.location = "' . ( admin_url('admin.php?page=wplannerfb') ) . '"; 
								return false;
							</script>';
							return false;
						}
					}
			
					if( $validAuth == false ) {
						// login url
						$loginUrl = $facebook->getLoginUrl(array('scope' => 'email,publish_stream,user_groups,manage_pages,offline_access'));
	
						$output .= '<a href="' . ($loginUrl) . '" style="width: 100px;" type="button" class="button-primary">'. (__( 'Authorizate app', WP_PLANNER_TEXTDOMAIN )) .'</a>';
					}
					
					// check if redirect from facebook to page
					$token = $facebook->getAccessToken();
					if(trim($token) != "" && $state != ""){
						// saving offline session into DB
						update_option('wplanner_token', $token);
						
						// get user profile
						$user_accounts = $facebook->api('me/accounts');
						
						$userPages = array();
						foreach ($user_accounts['data'] as $key => $value){
							if($value['category'] != 'Application'){
								$userPages['pages'][] = $value;
							}
						}
						
						// get user profile
						$user_groups = $facebook->api('me/groups');
						foreach ($user_groups['data'] as $key => $value){
							$userPages['groups'][] = $value;
						}
						
						if(count($userPages) > 0){
							update_option('wplanner_user_pages', json_encode($userPages));
							
							echo '
							<script type="text/javascript">
								window.location = "' . ( admin_url('admin.php?page=wplannerfb') ) . '"; 
								return false;
							</script>';
						}
					}
				}
			break;
			
			// Basic text input
			case 'listdatabase':
				global $wpdb;
				
				$output .= '<table cellspacing="0" class="widefat tag fixed" style="margin: 10px 0px 10px 0px;">
					<thead>
						<tr>';
				foreach ($value['options']['fields'] as $key => $val) {
					$output .= '<th scope="col" ' . ( isset($val['width']) && trim($val['width']) != "" ? 'width="' . ( $val['width'] ) . '"' : '') . '>' . ( $val['label'] ) . '</th>';
				}
				$output .= '</tr>
					</thead>
					<tbody class="list:tag">';

				// get entries
				$entries = $wpdb->get_results( "SELECT " . (implode(", ", array_keys($value['options']['fields']))) . " FROM " . ($value['options']['table']) . " WHERE 1=1", ARRAY_A );
				if (count($entries) > 0) {
					$cc = 0;
					foreach ($entries as $key => $entry) {

						$output .= '<tr class="' . ($cc % 2 ? 'alternate' : '') . '">';
						
						foreach ($value['options']['fields'] as $field_id => $field) {
						
							if($field['type'] == 'enum') {
							
								$output .= '<td>' . ( $field['values'][$entry[$field_id]] ) . '</td>';
								
							}else if($field['type'] == 'button') {
							
								if($field['action'] == 'delete') {
									$output .= '<td><a href="#" class="fbPPdeleteTask button">'.($value['options']['fields'][$field_id]['label'] ).'</td>';
								}else if($field['action'] == 'view') {
									$output .= '<td><a href="#" class="viewrow button">'.($value['options']['fields'][$field_id]['label'] ).'</td>';
								}
								
							}else if($field['type'] == 'serialize') {
								$pg = get_option('wplanner_user_pages');
								if(trim($pg) != ""){
									$pg = @json_decode($pg);
								}
								
								$post_to = '';
								$serialize = $entry[$field_id];
								$arr = unserialize($serialize);
								
								if( trim($arr['profile']) == 'on' ) {
									$post_to = '- Profile';
								}
								
								if( trim($arr['page_group']) != '' ) {
									$page_group = explode('##', $arr['page_group']);
									$post_to .= trim($post_to) != '' ? '<br />' : '';
									
									if($page_group[0] == 'page') {
										foreach($pg->pages as $k => $v) {
											if($v->id == $page_group[1]) {
												$post_to_title = $v->name;
											}
										}
									}else if($page_group[0] == 'group') {
										foreach($pg->groups as $k => $v) {
											if($v->id == $page_group[1]) {
												$post_to_title = $v->name;
											}
										}
									}
									
									$post_to .= "- ".(ucfirst($page_group[0])).": " . $post_to_title;
								}
								
								$output .= '<td>' . ( $post_to ) . '</td>';
								
							}else if($field['type'] == 'link') {
								$output .= '<td>' . (trim($field['text']) != '' ? sprintf($field['text'], substr(get_the_title($entry[$field_id]), 0, 30).'...', get_edit_post_link($entry[$field_id])) : $entry[$field_id]) . '</td>';
							}else if($field['type'] == 'schedule_info') {
								$output .= '<td>' . sprintf($field['before'], get_edit_post_link($entry[$field_id])) . (trim($field['text']) != '' ? $field['text'] : $entry[$field_id]) . $field['after'] . '</td>';
							}else{
								$output .= '<td>' . ($field['before'] . $entry[$field_id] . $field['after']) . '</td>';
							}
							
						}

						$output .= '</tr>';

						$cc++;
					}
				} else {
					$output .= '
							<tr class="alternate" id="tag-4">
								<td class="name column-name" colspan="' . (count($value['options']['fields'])) . '" align="center" style="padding:15px;"><strong style="color:#DADADA">No tasks scheduled</strong></td>
							</tr>';
				}
				$output .= '</tbody>
				</table>';
			break;
			
			// Textarea
			case 'textarea':
				$cols = '8';
				$ta_value = '';
				
				if( isset( $value['options'] ) ){
					$ta_options = $value['options'];
					if( isset( $ta_options['cols'] ) ){
						$cols = $ta_options['cols'];
					} else { $cols = '8'; }
				}
				
				$val = stripslashes( $val );
				
				$output .= '<textarea id="' . esc_attr( $value['id'] ) . '" class="wplannerfb-input" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" cols="'. esc_attr( $cols ) . '" rows="8">' . esc_textarea( $val ) . '</textarea>';
			break;
			
			// Select Box
			case ($value['type'] == 'select'):
				$output .= '<select class="wplannerfb-input" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" id="' . esc_attr( $value['id'] ) . '">';
				
				foreach ($value['options'] as $key => $option ) {
					$selected = '';
					 if( $val != '' ) {
						 if ( $val == $key) { $selected = ' selected="selected"';} 
					 }
					 $output .= '<option'. $selected .' value="' . esc_attr( $key ) . '">' . esc_html( $option ) . '</option>';
				 } 
				 $output .= '</select>';
			break;

			
			// Radio Box
			case "radio":
				$name = $option_name .'['. $value['id'] .']';
				foreach ($value['options'] as $key => $option) {
					$id = $option_name . '-' . $value['id'] .'-'. $key;
					$output .= '<input class="wplannerfb-input wplannerfb-radio" type="radio" name="' . esc_attr( $name ) . '" id="' . esc_attr( $id ) . '" value="'. esc_attr( $key ) . '" '. checked( $val, $key, false) .' /><label for="' . esc_attr( $id ) . '">' . esc_html( $option ) . '</label>';
				}
			break;
			
			// Image Selectors
			case "images":
				$name = $option_name .'['. $value['id'] .']';
				foreach ( $value['options'] as $key => $option ) {
					$selected = '';
					$checked = '';
					if ( $val != '' ) {
						if ( $val == $key ) {
							$selected = ' wplannerfb-radio-img-selected';
							$checked = ' checked="checked"';
						}
					}
					$output .= '<input type="radio" id="' . esc_attr( $value['id'] .'_'. $key) . '" class="wplannerfb-radio-img-radio" value="' . esc_attr( $key ) . '" name="' . esc_attr( $name ) . '" '. $checked .' />';
					$output .= '<div class="wplannerfb-radio-img-label">' . esc_html( $key ) . '</div>';
					$output .= '<img src="' . esc_url( $option ) . '" alt="' . $option .'" class="wplannerfb-radio-img-img' . $selected .'" onclick="document.getElementById(\''. esc_attr($value['id'] .'_'. $key) .'\').checked=true;" />';
				}
			break;
			
			// Checkbox
			case "checkbox":
				$output .= '<input id="' . esc_attr( $value['id'] ) . '" class="checkbox wplannerfb-input" type="checkbox" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" '. checked( $val, 1, false) .' />';
				$output .= '<label class="explain" for="' . esc_attr( $value['id'] ) . '">' . wp_kses( $explain_value, $allowedtags) . '</label>';
			break;
			
			// Multicheck
			case "multicheck":
				foreach ($value['options'] as $key => $option) {
					$checked = '';
					$label = $option;
					$option = preg_replace('/[^a-zA-Z0-9._\-]/', '', strtolower($key));

					$id = $option_name . '-' . $value['id'] . '-'. $option;
					$name = $option_name . '[' . $value['id'] . '][' . $option .']';

					if ( isset($val[$option]) ) {
						$checked = checked($val[$option], 1, false);
					}

					$output .= '<input id="' . esc_attr( $id ) . '" class="checkbox wplannerfb-input" type="checkbox" name="' . esc_attr( $name ) . '" ' . $checked . ' /><label for="' . esc_attr( $id ) . '">' . esc_html( $label ) . '</label>';
				}
			break;
			
			// Color picker
			case "color":
				$output .= '<div id="' . esc_attr( $value['id'] . '_picker' ) . '" class="colorSelector"><div style="' . esc_attr( 'background-color:' . $val ) . '"></div></div>';
				$output .= '<input class="wplannerfb-color" name="' . esc_attr( $option_name . '[' . $value['id'] . ']' ) . '" id="' . esc_attr( $value['id'] ) . '" type="text" value="' . esc_attr( $val ) . '" />';
			break; 
			
			// Uploader
			case "upload":
				$output .= wplanner_fb_medialibrary_uploader( $value['id'], $val, null ); // New AJAX Uploader using Media Library	
			break;
			
			// Typography
			case 'typography':	
			
				$typography_stored = $val;
				
				// Font Size
				$output .= '<select class="wplannerfb-typography wplannerfb-typography-size" name="' . esc_attr( $option_name . '[' . $value['id'] . '][size]' ) . '" id="' . esc_attr( $value['id'] . '_size' ) . '">';
				for ($i = 9; $i < 71; $i++) { 
					$size = $i . 'px';
					$output .= '<option value="' . esc_attr( $size ) . '" ' . selected( $typography_stored['size'], $size, false ) . '>' . esc_html( $size ) . '</option>';
				}
				$output .= '</select>';
			
				// Font Face
				$output .= '<select class="wplannerfb-typography wplannerfb-typography-face" name="' . esc_attr( $option_name . '[' . $value['id'] . '][face]' ) . '" id="' . esc_attr( $value['id'] . '_face' ) . '">';
				
				$faces = wplanner_fb_recognized_font_faces();
				foreach ( $faces as $key => $face ) {
					$output .= '<option value="' . esc_attr( $key ) . '" ' . selected( $typography_stored['face'], $key, false ) . '>' . esc_html( $face ) . '</option>';
				}			
				
				$output .= '</select>';	

				// Font Weight
				$output .= '<select class="wplannerfb-typography wplannerfb-typography-style" name="'.$option_name.'['.$value['id'].'][style]" id="'. $value['id'].'_style">';

				/* Font Style */
				$styles = wplanner_fb_recognized_font_styles();
				foreach ( $styles as $key => $style ) {
					$output .= '<option value="' . esc_attr( $key ) . '" ' . selected( $typography_stored['style'], $key, false ) . '>'. $style .'</option>';
				}
				$output .= '</select>';

				// Font Color		
				$output .= '<div id="' . esc_attr( $value['id'] ) . '_color_picker" class="colorSelector"><div style="' . esc_attr( 'background-color:' . $typography_stored['color'] ) . '"></div></div>';
				$output .= '<input class="wplannerfb-color wplannerfb-typography wplannerfb-typography-color" name="' . esc_attr( $option_name . '[' . $value['id'] . '][color]' ) . '" id="' . esc_attr( $value['id'] . '_color' ) . '" type="text" value="' . esc_attr( $typography_stored['color'] ) . '" />';

			break;
			
			// Background
			case 'background':
				
				$background = $val;
				
				// Background Color		
				$output .= '<div id="' . esc_attr( $value['id'] ) . '_color_picker" class="colorSelector"><div style="' . esc_attr( 'background-color:' . $background['color'] ) . '"></div></div>';
				$output .= '<input class="wplannerfb-color wplannerfb-background wplannerfb-background-color" name="' . esc_attr( $option_name . '[' . $value['id'] . '][color]' ) . '" id="' . esc_attr( $value['id'] . '_color' ) . '" type="text" value="' . esc_attr( $background['color'] ) . '" />';
				
				// Background Image - New AJAX Uploader using Media Library
				if (!isset($background['image'])) {
					$background['image'] = '';
				}
				
				$output .= wplanner_fb_medialibrary_uploader( $value['id'], $background['image'], null, '',0,'image');
				$class = 'wplannerfb-background-properties';
				if ( '' == $background['image'] ) {
					$class .= ' hide';
				}
				$output .= '<div class="' . esc_attr( $class ) . '">';
				
				// Background Repeat
				$output .= '<select class="wplannerfb-background wplannerfb-background-repeat" name="' . esc_attr( $option_name . '[' . $value['id'] . '][repeat]'  ) . '" id="' . esc_attr( $value['id'] . '_repeat' ) . '">';
				$repeats = wplanner_fb_recognized_background_repeat();
				
				foreach ($repeats as $key => $repeat) {
					$output .= '<option value="' . esc_attr( $key ) . '" ' . selected( $background['repeat'], $key, false ) . '>'. esc_html( $repeat ) . '</option>';
				}
				$output .= '</select>';
				
				// Background Position
				$output .= '<select class="wplannerfb-background wplannerfb-background-position" name="' . esc_attr( $option_name . '[' . $value['id'] . '][position]' ) . '" id="' . esc_attr( $value['id'] . '_position' ) . '">';
				$positions = wplanner_fb_recognized_background_position();
				
				foreach ($positions as $key=>$position) {
					$output .= '<option value="' . esc_attr( $key ) . '" ' . selected( $background['position'], $key, false ) . '>'. esc_html( $position ) . '</option>';
				}
				$output .= '</select>';
				
				// Background Attachment
				$output .= '<select class="wplannerfb-background wplannerfb-background-attachment" name="' . esc_attr( $option_name . '[' . $value['id'] . '][attachment]' ) . '" id="' . esc_attr( $value['id'] . '_attachment' ) . '">';
				$attachments = wplanner_fb_recognized_background_attachment();
				
				foreach ($attachments as $key => $attachment) {
					$output .= '<option value="' . esc_attr( $key ) . '" ' . selected( $background['attachment'], $key, false ) . '>' . esc_html( $attachment ) . '</option>';
				}
				$output .= '</select>';
				$output .= '</div>';
			
			break;  
			
			// Info
			case "info":
				$class = 'section';
				if ( isset( $value['type'] ) ) {
					$class .= ' section-' . $value['type'];
				}
				if ( isset( $value['class'] ) ) {
					$class .= ' ' . $value['class'];
				}
				if ( isset( $value['id'] ) ) {
					$id = $value['id'];
				}

				$output .= '<div id="section-' . esc_attr( $id ) . '" class="' . esc_attr( $class ) . '">' . "\n";
				if ( isset($value['name']) ) {
					$output .= '<h4 class="heading">' . esc_html( $value['name'] ) . '</h4>' . "\n";
				}
				if ( $value['desc'] ) {
					$output .= apply_filters('wplanner_fb_sanitize_info', $value['desc'] ) . "\n";
				}
				$output .= '<div class="clear"></div></div>' . "\n";
			break;                       
			
			// Heading for Navigation
			case "heading":
				if ($counter >= 2) {
				   $output .= '</div>'."\n";
				}
				$jquery_click_hook = preg_replace('/[^a-zA-Z0-9._\-]/', '', strtolower($value['name']) );
				$jquery_click_hook = "wplannerfb-option-" . $jquery_click_hook;
				$menu .= '<a id="'.  esc_attr( $jquery_click_hook ) . '-tab" class="nav-tab" title="' . esc_attr( $value['name'] ) . '" href="' . esc_attr( '#'.  $jquery_click_hook ) . '">' . esc_html( $value['name'] ) . '</a>';
				$output .= '<div class="ww_tab" id="' . esc_attr( $jquery_click_hook ) . '">';
				$output .= '<h3>' . esc_html( $value['name'] ) . '</h3>' . "\n";
				break;
			}

			if ( ( $value['type'] != "heading" ) && ( $value['type'] != "info" ) && ( $value['type'] != "listdatabase" ) ) {
				if ( $value['type'] != "checkbox" ) {
					$output .= '<br/>';
				}
				$output .= '</div>';
				if ( $value['type'] != "checkbox" ) {
					$output .= '<div class="explain">' . wp_kses( $explain_value, $allowedtags) . '</div>'."\n";
				}
				$output .= '<div class="clear"></div></div></div>'."\n";
			}
		}
		$output .= '</div>';
		return array($output,$menu);
	}
}